{ Interface from GMP to Borland Delphi. }

unit gmp;

interface

uses SysUtils;

type
  MP_INT = record
  	     alloc: Integer;
	     size: Integer;
	     d: ^LongInt;
	   end;

  AllocProc = function(size: Integer): PChar;
  ReallocProc = function(old: PChar; oldsize, newsize: Integer): PChar;
  FreeProc = procedure(addr: PChar; size: Integer);
  LogProc = procedure(msg, context: PChar);

procedure mp_set_memory_functions(alloc: AllocProc;
				  realloc: ReallocProc;
				  free: FreeProc);
procedure mpz_init(var x: MP_INT);
procedure mpz_set(var x: MP_INT; var value: MP_INT);
procedure mpz_set_ui(var x: MP_INT; value: LongInt);
procedure mpz_set_si(var x: MP_INT; value: LongInt);
function mpz_set_str(var x: MP_INT; value: PChar; base: Integer): Integer;
procedure mpz_init_set(var x, value: MP_INT);
procedure mpz_init_set_ui(var x: MP_INT; value: LongInt);
procedure mpz_init_set_si(var x: MP_INT; value: LongInt);
procedure mpz_init_set_str(var x: MP_INT; value: PChar; base: Integer);
function mpz_get_ui(var x: MP_INT): LongInt;
function mpz_get_si(var x: MP_INT): LongInt;
function mpz_get_str(buf: PChar; base: Integer; var x: MP_INT): PChar;
procedure mpz_clear(var x: MP_INT);
procedure mpz_add(var dest, x, y: MP_INT);
procedure mpz_add_ui(var dest, x: MP_INT; y: LongInt);
procedure mpz_sub(var dest, x, y: MP_INT);
procedure mpz_sub_ui(var dest, x: MP_INT; y: LongInt);
procedure mpz_mul(var dest, x, y: MP_INT);
procedure mpz_mul_ui(var dest, x: MP_INT; y: LongInt);
procedure mpz_div(var dest, x, y: MP_INT);
procedure mpz_div_ui(var dest, x: MP_INT; y: LongInt);
procedure mpz_mod(var dest, x, y: MP_INT);
procedure mpz_mod_ui(var dest, x: MP_INT; y: LongInt);
function mpz_probab_prime_p(var x: MP_INT; iterations: Integer): Integer;
procedure mpz_pow_ui(var res, base: MP_INT; exp: LongInt);
procedure mpz_powm(var res, base, exp, modulus: MP_INT);
procedure mpz_gcd(var w, u, v: MP_INT);
procedure mpz_neg(var dest, x: MP_INT);
procedure mpz_abs(var dest, x: MP_INT);
function mpz_cmp(var x, y: MP_INT): Integer;
function mpz_cmp_ui(var x: MP_INT; y: LongInt): Integer;
function mpz_cmp_si(var x: MP_INT; y: LongInt): Integer;
procedure mpz_mul_2exp(var w, u: MP_INT; cnt: LongInt);
procedure mpz_div_2exp(var w, u: MP_INT; cnt: LongInt);
procedure mpz_mod_2exp(var w, u: MP_INT; cnt: LongInt);
procedure mpz_and(var dest, x, y: MP_INT);
procedure mpz_ior(var dest, x, y: MP_INT);
function mpz_sizeinbase(var x: MP_INT; base: Integer): Integer;

procedure gmp_set_log(proc: LogProc; context: PChar);

implementation

procedure mp_set_memory_functions(alloc: AllocProc;
				  realloc: ReallocProc;
				  free: FreeProc); external 'GMP';
procedure mpz_init(var x: MP_INT); external 'GMP';
procedure mpz_set(var x: MP_INT; var value: MP_INT); external 'GMP';
procedure mpz_set_ui(var x: MP_INT; value: LongInt); external 'GMP';
procedure mpz_set_si(var x: MP_INT; value: LongInt); external 'GMP';
function mpz_set_str(var x: MP_INT; value: PChar; base: Integer): Integer;
  external 'GMP';
procedure mpz_init_set(var x, value: MP_INT); external 'GMP';
procedure mpz_init_set_ui(var x: MP_INT; value: LongInt); external 'GMP';
procedure mpz_init_set_si(var x: MP_INT; value: LongInt); external 'GMP';
procedure mpz_init_set_str(var x: MP_INT; value: PChar; base: Integer);
  external 'GMP';
function mpz_get_ui(var x: MP_INT): LongInt; external 'GMP';
function mpz_get_si(var x: MP_INT): LongInt; external 'GMP';
function mpz_get_str(buf: PChar; base: Integer; var x: MP_INT): PChar;
  external 'GMP';
procedure mpz_clear(var x: MP_INT); external 'GMP';
procedure mpz_add(var dest, x, y: MP_INT); external 'GMP';
procedure mpz_add_ui(var dest, x: MP_INT; y: LongInt); external 'GMP';
procedure mpz_sub(var dest, x, y: MP_INT); external 'GMP';
procedure mpz_sub_ui(var dest, x: MP_INT; y: LongInt); external 'GMP';
procedure mpz_mul(var dest, x, y: MP_INT); external 'GMP';
procedure mpz_mul_ui(var dest, x: MP_INT; y: LongInt); external 'GMP';
procedure mpz_div(var dest, x, y: MP_INT); external 'GMP';
procedure mpz_div_ui(var dest, x: MP_INT; y: LongInt); external 'GMP';
procedure mpz_mod(var dest, x, y: MP_INT); external 'GMP';
procedure mpz_mod_ui(var dest, x: MP_INT; y: LongInt); external 'GMP';
function mpz_probab_prime_p(var x: MP_INT; iterations: Integer): Integer;
  external 'GMP';
procedure mpz_pow_ui(var res, base: MP_INT; exp: LongInt); external 'GMP';
procedure mpz_powm(var res, base, exp, modulus: MP_INT); external 'GMP';
procedure mpz_gcd(var w, u, v: MP_INT); external 'GMP';
procedure mpz_neg(var dest, x: MP_INT); external 'GMP';
procedure mpz_abs(var dest, x: MP_INT); external 'GMP';
function mpz_cmp(var x, y: MP_INT): Integer; external 'GMP';
function mpz_cmp_ui(var x: MP_INT; y: LongInt): Integer; external 'GMP';
function mpz_cmp_si(var x: MP_INT; y: LongInt): Integer; external 'GMP';
procedure mpz_mul_2exp(var w, u: MP_INT; cnt: LongInt); external 'GMP';
procedure mpz_div_2exp(var w, u: MP_INT; cnt: LongInt); external 'GMP';
procedure mpz_mod_2exp(var w, u: MP_INT; cnt: LongInt); external 'GMP';
procedure mpz_and(var dest, x, y: MP_INT); external 'GMP';
procedure mpz_ior(var dest, x, y: MP_INT); external 'GMP';
function mpz_sizeinbase(var x: MP_INT; base: Integer): Integer; external 'GMP';

procedure gmp_set_log(proc: LogProc; context: PChar); external 'GMP';

end.

